@@ -12,7 +12,7 @@ extern void fx_chat_initialize(FxChat* fxchat);
 
 extern void fx_chat_free(FxChat* fxchat);
 
-extern void fx_chat_destroy(GtkWidget* widget , gpointer data);
+extern void fx_chat_destroy(GtkWidget* UNUSED(widget) , gpointer data);
 
 extern void fx_chat_send_message(FxChat* fxchat);
 
@@ -22,17 +22,19 @@ extern void fx_chat_nudge_in_thread(FxChat* fxchat);
 
 extern void fx_chat_on_tophone_clicked(GtkWidget* widget , gpointer data);
 
-extern void fx_chat_on_close_clicked(GtkWidget* widget , gpointer data);
+extern void fx_chat_on_close_clicked(GtkWidget* UNUSED(widget) , gpointer data);
 
-extern void fx_chat_on_send_clicked(GtkWidget* widget , gpointer data);
+extern void fx_chat_on_send_clicked(GtkWidget* UNUSED(widget) , gpointer data);
 
-extern void fx_chat_on_history_clicked(GtkWidget* widget , gpointer data);
+extern void fx_chat_on_history_clicked(GtkWidget* UNUSED(widget) , gpointer data);
 
-extern gboolean fx_chat_on_key_pressed(GtkWidget* widget , GdkEventKey* event , gpointer data);
+extern gboolean fx_chat_on_key_pressed(GtkWidget* UNUSED(widget)
+		, GdkEventKey* event , gpointer data);
 
-extern gboolean fx_chat_on_key_released(GtkWidget* widget , GdkEventKey* event , gpointer data);
+extern gboolean fx_chat_on_key_released(GtkWidget* UNUSED(widget)
+		, GdkEventKey* event , gpointer data);
 
-extern void fx_chat_on_nudge_clicked(GtkWidget* widget , gpointer data);
+extern void fx_chat_on_nudge_clicked(GtkWidget* UNUSED(widget) , gpointer data);
 
 /*private*/
 
