@@ -60,6 +60,8 @@ extern void fx_main_process_invitation(FxMain* fxmain , const char* sipmsg);
 
 extern void fx_main_process_incoming(FxMain* fxmain , FetionSip* sip , const char* sipmsg);
 
+extern void fx_main_process_sipc(FxMain* fxmain , const char* sipmsg);
+
 extern void	fx_main_process_deregistration(FxMain* fxmain);
 
 extern void fx_main_process_syncuserinfo(FxMain* fxmain , const char* xml);
@@ -115,6 +117,8 @@ extern FetionSip* fx_list_find_sip_by_sipuri(FxList* fxlist , const char* sipuri
 
 extern void fx_list_remove_sip_by_sipuri(FxList* fxlist , const char* sipuri);
 
+extern void fx_list_remove_pg_by_sipuri(FxList* fxlist , const char* sipuri);
+
 extern FxChat* fx_list_find_chat_by_sipuri(FxList* clist , const char* sipuri);
 
 extern void fx_list_remove_chat_by_sipuri(FxList* fxlist , const char* sipuri);
