@@ -78,9 +78,13 @@ typedef struct
 typedef struct
 {
 	GtkWidget *treeView;
+	GtkWidget *noPgLabel;
+	GtkWidget *pgTreeView;
 	GtkWidget *searchbox;
 	GtkTreeStore *treeModel;
 	GtkWidget *scrollWindow;
+	GtkWidget *pgScrollWindow;
+	GtkWidget *noLabelScrollWindow;
 } FxTree;
 
 typedef struct
@@ -90,6 +94,7 @@ typedef struct
 	FxList* slist;				 /*  sip list wicth is now listening			 */
 	FxList* tlist;				 /*  time out args list							 */
 	FxList* shlist;				 /*	 share content window list		   			 */
+	FxList* pglist;
 #ifdef HAVE_LIBNOTIFY
 	NotifyNotification *notify;
 #endif
@@ -477,4 +482,36 @@ typedef struct
 	GtkWidget *view;
 }FxSearch;
 
+typedef struct
+{
+	FxMain *fxmain;
+
+	int hasFocus;
+	PGGroup *pggroup;
+	GtkWidget *window;
+	GtkWidget *image;
+	GtkWidget *nameLabel;
+	GtkWidget *otherLabel;
+	GtkWidget *phoneButton;
+	GtkWidget *sendView;
+	GtkWidget *recvView;
+	GtkWidget *toolbar;
+	GtkWidget *noticeView;
+	GtkWidget *treeView;
+} FxPGGroup;
+
+typedef struct
+{
+	FxMain *fxmain;
+	PGGroup *pggroup;
+	GtkWidget *window;
+	GtkWidget *image;
+	GtkWidget *sidEntry;
+	GtkWidget *nameEntry;
+	GtkWidget *leaderEntry;
+	GtkWidget *timeEntry;
+	GtkWidget *introView;
+	GtkWidget *bulletinView;
+} FxPGProfile;
+
 #endif
