@@ -32,7 +32,12 @@
 #define STATE_HIDDEN 0
 #define STATE_NOTAPRESENCE -1
 
-
+/**
+ * create a User object and initialize it with number and password
+ * @no Phone number or Fetion number
+ * @password Nothing special , just your fetion password
+ * @return The user object created
+ */
 extern User* fetion_user_new(const char* no , const char* password);
 
 extern void fetion_user_set_userid(User* user , const char* userid);
@@ -49,18 +54,69 @@ extern void fetion_user_set_verification_code(User* user , const char* code);
 
 extern void fetion_user_free(User* user);
 
+/**
+ * upload portrait
+ * @param user Global User object
+ * @param filename The absolute filepath of the portrait file to be uploaded
+ * @return 1 if success , or else -1
+ */
 extern int fetion_user_upload_portrait(User* user , const char* filename);
 
+/**
+ * download portrait of specified user
+ * @param user Global User object
+ * @param sipuri sip uri of the user whose portrait will be downloaded
+ */
 extern int fetion_user_download_portrait(User* user , const char* sipuri);
 
+/**
+ * download portrait of specified sipuri with
+ * the specified server name and server path of the portrait server
+ * @param user Global User object
+ * @param sipuri sip uri of the user(or Feiton Group) whose portrait will be downloaded
+ * @param server The host name of the portrait server
+ * @param portraitPath The uri path of the portrait server,like '/HD00S/getportrait.aspx'
+ * @return 1 if success , or else -1
+ */
+extern int fetion_user_download_portrait_with_uri(User* user , const char* sipuri
+       	, const char *server , const char *portraitPath);
+
+/**
+ * modify the user`s online state such as 'Online' , 'Busy' , etc..
+ * @param user Global User object
+ * @param state The online state type
+ * @return 1 if success , or else -1
+ */
 extern int fetion_user_set_state(User* user , StateType state);
 
+/**
+ * modify the user`s personal signature
+ * @param user Global User object
+ * @param moodphrase The new personal signature string
+ * @return 1 if success , or else -1
+ */
 extern int fetion_user_set_moodphrase(User* user , const char* moodphrase);
 
+/**
+ * reload the user`s detail information from the sipc server
+ * @param user Global User object
+ * @return 1 if  success , or else -1
+ */
 extern int fetion_user_update_info(User* user);
 
+/**
+ * send a keep-alive message to the sipc server to tell that the client 
+ * is not offline.This function should be called periodically.
+ * @param user Global User object
+ * @return 1 if success , or else -1
+ */
 extern int fetion_user_keep_alive(User* user);
 
+/**
+ * traverse the two-way linked list of user group
+ * @param head the list header
+ * @param gl the list cursor
+ */
 #define foreach_grouplist(head , gl) \
 	for(gl = head ; (gl = gl->next) != head ;)
 
@@ -80,21 +136,8 @@ extern Verification* fetion_verification_new();
 
 extern void fetion_verification_free(Verification* ver);
 
-/*private*/
-extern int fetion_user_download_portrait_again(const char* filepath , const char* buf , Proxy *proxy);
-
 extern Contact* fetion_user_parse_presence_body(const char* body , User* user);
 
 extern Contact* fetion_user_parse_syncuserinfo_body(const char* body , User* user);
 
-extern char* generate_set_state_body(StateType state);
-
-extern char* generate_set_moodphrase_body(const char* customConfigVersion
-				, const char* customConfig , const char* personalVersion ,  const char* moodphrase);
-
-extern char* generate_update_information_body(User* user);
-
-extern char* generate_keep_alive_body();
-
-extern void parse_set_moodphrase_response(User* user , const char* sipmsg);
 #endif
