@@ -18,7 +18,33 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include "fetion_include.h"
+#include <openfetion.h>
+/*private */
+
+static char* generate_subscribe_body(const char* version);
+
+static char* generate_contact_info_body(const char* userid);
+
+static char* generate_contact_info_by_no_body(const char* no , NumberType nt);
+
+static char* generate_set_mobileno_perssion(const char* userid , int show);
+
+static char* generate_set_displayname_body(const char* userid , const char* name);
+
+static char* generate_move_to_group_body(const char* userid , int buddylist);
+
+static char* generate_delete_buddy_body(const char* userid);
+
+static char* generate_add_buddy_body(const char* no , NumberType notype
+								, int buddylist , const char* localname
+								, const char* desc , int phraseid);
+
+static char* generate_handle_contact_request_body(const char* sipuri
+								, const char* userid , const char* localname
+								, int buddylist , int result );
+static Contact* parse_handle_contact_request_response(const char* sipmsg);
+static Contact* parse_add_buddy_response(const char* sipmsg , int* statuscode);
+
 Contact* fetion_contact_new()
 {
 	Contact* list = (Contact*)malloc(sizeof(Contact));
@@ -145,6 +171,31 @@ Contact* fetion_contact_get_contact_info(User* user , const char* userid)
 	}
 	return contact;
 }
+
+int fetion_contact_has_ungrouped(Contact *contactlist)
+{
+	Contact *cur;
+
+	foreach_contactlist(contactlist , cur){
+		if(cur->groupid == BUDDY_LIST_NOT_GROUPED)
+		    return 1;
+	}
+	return 0;
+
+}
+
+int fetion_contact_has_strangers(Contact *contactlist)
+{
+	Contact *cur;
+
+	foreach_contactlist(contactlist , cur){
+		if(cur->groupid == BUDDY_LIST_STRANGER)
+		    return 1;
+	}
+	return 0;
+
+}
+
 Contact* fetion_contact_get_contact_info_by_no(User* user , const char* no , NumberType nt)
 {
 	FetionSip* sip = user->sip;
@@ -695,7 +746,7 @@ Contact* parse_contact_info_by_no_response(const char* sipmsg)
 	xmlFreeDoc(doc);
 	return contact;
 }
-Contact* parse_add_buddy_response(const char* sipmsg , int* statuscode)
+static Contact* parse_add_buddy_response(const char* sipmsg , int* statuscode)
 {
 	char *pos;
 	Contact* contact;
