@@ -18,10 +18,25 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include "fetion_include.h"
+#include <openfetion.h>
 #include <openssl/rsa.h>
 #include <openssl/sha.h>
 
+/*private method*/
+static char* generate_auth_body(User* user);
+static void parse_personal_info(xmlNodePtr node , User* user);
+static void parse_contact_list(xmlNodePtr node , User* user);
+static void parse_stranger_list(xmlNodePtr node , User* user);
+static void parse_ssi_auth_success(xmlNodePtr node , User* user);
+static void parse_ssi_auth_failed(xmlNodePtr node , User* user);
+static unsigned char* strtohex(const char* in , int* len) ;
+static char* hextostr(const unsigned char* in , int len) ;
+static char* hash_password_v1(const unsigned char* b0 , int b0len , const unsigned char* password , int psdlen);
+static char* hash_password_v2(const char* userid , const char* passwordhex);
+static char* hash_password_v4(const char* userid , const char* password);
+static char* generate_cnouce() ;
+static unsigned char* decode_base64(const char* in , int* len);
+
 
 char* generate_response(const char* nouce , const char* userid 
 		, const char* password , const char* publickey , const char* key)
@@ -177,8 +192,7 @@ char* ssi_auth_action(User* user)
 		ret = tcp_connection_connect_with_proxy(ssl , ssi_ip , 443 , user->config->proxy);
 		if(ret < 0)
 			return NULL;
-	}
-	else{
+	}else{
 		if(tcp_connection_connect(ssl , ssi_ip , 443) < 0)
 			return NULL;
 	}
@@ -186,8 +200,7 @@ char* ssi_auth_action(User* user)
 	debug_info("Start ssi login with %s password , user number %s"
 			, passwordType == 1 ? "v3Temp" : "v4"
 			, user->loginType == LOGIN_TYPE_MOBILENO ? user->mobileno : user->sId);
-	if(ssl_connection_start(ssl) == -1)
-	{
+	if(ssl_connection_start(ssl) == -1){
 		debug_error("Initialize ssl failed,please retry or check your system`s configuration");
 		return NULL;
 	}
@@ -417,7 +430,24 @@ int parse_sipc_auth_response(const char* auth_response , User* user)
 	xmlFreeDoc(doc);
 	return 1;
 }
-char* generate_auth_body(User* user)
+
+char* generate_aes_key()
+{
+	char* key = (char*)malloc(65);
+	memset( key , 0 , 65 );
+	sprintf( key , "%04x%04x%04x%04x%04x%04x%04x"
+			"%04x%04x%04x%04x%04x%04x%04x%04x%04x" , 
+			rand() & 0xFFFF , rand() & 0xFFFF , 
+			rand() & 0xFFFF , rand() & 0xFFFF , 
+			rand() & 0xFFFF , rand() & 0xFFFF , 
+			rand() & 0xFFFF , rand() & 0xFFFF , 
+			rand() & 0xFFFF , rand() & 0xFFFF , 
+			rand() & 0xFFFF , rand() & 0xFFFF ,
+			rand() & 0xFFFF , rand() & 0xFFFF,
+			rand() & 0xFFFF , rand() & 0xFFFF );
+	return key;
+}
+static char* generate_auth_body(User* user)
 {
 	char basexml[] = "<args></args>";
 	char state[5];
@@ -460,7 +490,7 @@ char* generate_auth_body(User* user)
 	xmlFreeDoc(doc);
 	return xml_convert(buf);
 }
-void parse_personal_info(xmlNodePtr node , User* user)
+static void parse_personal_info(xmlNodePtr node , User* user)
 {
 	xmlChar *buf;
 	char *pos;
@@ -527,7 +557,7 @@ void parse_personal_info(xmlNodePtr node , User* user)
 		xmlFree(buf);
 	}
 }
-void parse_contact_list(xmlNodePtr node , User* user)
+static void parse_contact_list(xmlNodePtr node , User* user)
 {
 	xmlChar* buf = NULL;
 	xmlNodePtr node1 , node2;
@@ -605,7 +635,7 @@ void parse_contact_list(xmlNodePtr node , User* user)
 	}
 	debug_info("Read contact list complete");
 }
-void parse_stranger_list(xmlNodePtr node , User* user)
+static void parse_stranger_list(xmlNodePtr node , User* user)
 {
 	xmlNodePtr node1 = node->xmlChildrenNode;
 	xmlChar *buf = NULL;
@@ -630,7 +660,7 @@ void parse_stranger_list(xmlNodePtr node , User* user)
 		node1 = node1->next;
 	}
 }
-void parse_ssi_auth_success(xmlNodePtr node , User* user)
+static void parse_ssi_auth_success(xmlNodePtr node , User* user)
 {
 	char* pos;
 	pos = (char*)xmlGetProp(node , BAD_CAST "uri");
@@ -646,7 +676,7 @@ void parse_ssi_auth_success(xmlNodePtr node , User* user)
 	strcpy(user->userId , pos);
 	free(pos);
 }
-void parse_ssi_auth_failed(xmlNodePtr node , User* user)
+static void parse_ssi_auth_failed(xmlNodePtr node , User* user)
 {
 	Verification* ver = fetion_verification_new();
 	ver->algorithm = (char*)xmlGetProp(node , BAD_CAST "algorithm");
@@ -655,7 +685,7 @@ void parse_ssi_auth_failed(xmlNodePtr node , User* user)
 	ver->tips	   = (char*)xmlGetProp(node , BAD_CAST "tips");
 	user->verification = ver;
 }
-unsigned char* strtohex(const char* in , int* len) 
+static unsigned char* strtohex(const char* in , int* len) 
 {
 	unsigned char* out = (unsigned char*)malloc(strlen(in)/2 );
 	int i = 0 , j = 0 , k = 0 ,length = 0;
@@ -676,7 +706,7 @@ unsigned char* strtohex(const char* in , int* len)
 		*len = length;
 	return out;
 }
-char* hextostr(const unsigned char* in , int len) 
+static char* hextostr(const unsigned char* in , int len) 
 {
 	char* res = (char*)malloc(len * 2 + 1);
 	int i = 0;
@@ -694,7 +724,7 @@ char* hextostr(const unsigned char* in , int len)
 	};
 	return res;
 }
-char* hash_password_v1(const unsigned char* b0 , int b0len , const unsigned char* password , int psdlen) 
+static char* hash_password_v1(const unsigned char* b0 , int b0len , const unsigned char* password , int psdlen) 
 {
 	unsigned char* dst = (unsigned char*)malloc(b0len + psdlen + 1);
 	unsigned char tmp[20];
@@ -711,7 +741,7 @@ char* hash_password_v1(const unsigned char* b0 , int b0len , const unsigned char
 	res = hextostr(tmp , 20);
 	return res;
 }
-char* hash_password_v2(const char* userid , const char* passwordhex) 
+static char* hash_password_v2(const char* userid , const char* passwordhex) 
 {
 	int id = atoi(userid);
 	char* res;
@@ -724,7 +754,7 @@ char* hash_password_v2(const char* userid , const char* passwordhex)
 	free(bpsd);
 	return res;
 }
-char* hash_password_v4(const char* userid , const char* password)
+static char* hash_password_v4(const char* userid , const char* password)
 {
 	const char* domain = "fetion.com.cn:";
 	char *res , *dst;
@@ -745,23 +775,7 @@ char* hash_password_v4(const char* userid , const char* password)
 	free(res);
 	return dst;
 }
-char* generate_aes_key()
-{
-	char* key = (char*)malloc(65);
-	memset( key , 0 , 65 );
-	sprintf( key , "%04x%04x%04x%04x%04x%04x%04x"
-			"%04x%04x%04x%04x%04x%04x%04x%04x%04x" , 
-			rand() & 0xFFFF , rand() & 0xFFFF , 
-			rand() & 0xFFFF , rand() & 0xFFFF , 
-			rand() & 0xFFFF , rand() & 0xFFFF , 
-			rand() & 0xFFFF , rand() & 0xFFFF , 
-			rand() & 0xFFFF , rand() & 0xFFFF , 
-			rand() & 0xFFFF , rand() & 0xFFFF ,
-			rand() & 0xFFFF , rand() & 0xFFFF,
-			rand() & 0xFFFF , rand() & 0xFFFF );
-	return key;
-}
-char* generate_cnouce()
+static char* generate_cnouce()
 {
 	char* cnouce = (char*)malloc(33);
 	memset( cnouce , 0 , 33 );
@@ -773,7 +787,7 @@ char* generate_cnouce()
 	return cnouce;
 }
 
-unsigned char* decode_base64(const char* in , int* len)
+static unsigned char* decode_base64(const char* in , int* len)
 {
  	unsigned int n , t = 0 , c = 0;
 	unsigned char* res;
