@@ -18,7 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include "fetion_include.h"
+#include <openfetion.h>
 
 char buffer[1025];
 int callid = 1;
@@ -56,7 +56,14 @@ SipHeader* fetion_sip_header_new(const char* name , const char* value)
 void fetion_sip_set_type(FetionSip* sip , SipType type)
 {
 	sip->type = type;
+	sip->callid = callid;
 }
+
+void fetion_sip_set_callid(FetionSip* sip , int callid)
+{
+	sip->callid = callid;
+}
+
 SipHeader* fetion_sip_authentication_header_new(const char* response)
 {
 	int len;
@@ -145,6 +152,21 @@ SipHeader* fetion_sip_event_header_new(int eventType)
 		case SIP_EVENT_SENDDIRECTCATSMS :
 			strcpy(event , "SendDirectCatSMS");
 			break;
+		case SIP_EVENT_PGGETGROUPLIST:
+			strcpy(event , "PGGetGroupList");
+			break;
+		case SIP_EVENT_PGGETGROUPINFO:
+			strcpy(event , "PGGetGroupInfo");
+			break;
+		case SIP_EVENT_PGPRESENCE:
+			strcpy(event , "PGPresence");
+			break;
+		case SIP_EVENT_PGGETGROUPMEMBERS:
+			strcpy(event , "PGGetGroupMembers");
+			break;
+		case SIP_EVENT_PGSENDCATSMS:
+			strcpy(event , "PGSendCatSMS");
+			break;
 		default:
 			break;
 	}
@@ -205,6 +227,11 @@ char* fetion_sip_to_string(FetionSip* sip , const char* body)
 		case SIP_INCOMING	  : strcpy(type , "IN");
 			break;
 		case SIP_OPTION 	  : strcpy(type , "O");
+			break;
+		case SIP_INVITATION	: strcpy(type , "I");
+			break;
+		case SIP_ACKNOWLEDGE	: strcpy(type , "A");
+			break;
 		default:
 			break;
 	};
@@ -217,7 +244,7 @@ char* fetion_sip_to_string(FetionSip* sip , const char* body)
 	sprintf(buf , "F: %s\r\n" , sip->from);
 	strcat(res , buf);
 	bzero(buf , sizeof(buf));
-	sprintf(buf , "I: %d\r\n" , callid);
+	sprintf(buf , "I: %d\r\n" , sip->callid);
 	strcat(res , buf);
 	bzero(buf , sizeof(buf));
 	sprintf(buf , "Q: 2 %s\r\n" , type);
@@ -259,6 +286,7 @@ void fetion_sip_free(FetionSip* sip)
 		tcp_connection_free(sip->tcp);
 	free(sip);
 }
+
 char* fetion_sip_get_sid_by_sipuri(const char* sipuri)
 {
 	char *res , *pos;
@@ -270,6 +298,21 @@ char* fetion_sip_get_sid_by_sipuri(const char* sipuri)
 	strncpy(res , pos , n);
 	return res;
 }
+
+char* fetion_sip_get_pgid_by_sipuri(const char *pgsipuri)
+{
+	char *res , *pos;
+	int n;
+	if(strstr(pgsipuri , "PG") == NULL)
+	    return NULL;
+	pos = strstr(pgsipuri , "PG") + 2;
+	n = strlen(pos) - (strstr(pos , "@") == 0 ? 0 : strlen(strstr(pos , "@"))) ;
+	res = (char*)malloc(n + 1);
+	memset(res , 0 , n + 1);
+	strncpy(res , pos , n);
+	return res;
+}
+
 int fetion_sip_get_attr(const char* sip , const char* name , char* result)
 {
 	char m_name[5];
@@ -299,16 +342,20 @@ int fetion_sip_get_length(const char* sip)
 }
 int fetion_sip_get_code(const char* sip)
 {
-	char *pos , res[4];
+	char *pos , res[32];
 	int n;
-	pos = strstr(sip , " ") + 1;
+	if(strstr(sip , "4.0 ") == NULL)
+	    return 400;
+	pos = strstr(sip , "4.0 ") + 4;
+	if(strstr(pos , " ") == NULL)
+	    return 400;
 	n = strlen(pos) - strlen(strstr(pos , " "));
 	strncpy(res , pos , n);
 	return atoi(res);
 }
 int fetion_sip_get_type(const char* sip)
 {
-	char res[10];
+	char res[128];
 	int n;
 	n = strlen(sip) - strlen(strstr(sip , " "));
 	bzero(res , sizeof(res));
@@ -333,9 +380,13 @@ char* fetion_sip_get_response(FetionSip* sip)
 	char *res;
 	unsigned int len , n , c , c1;
 	char buf[2048];
-	bzero(buf , sizeof(buf));
+
+	memset(buf , 0 , sizeof(buf));
+
 	c = tcp_connection_recv(sip->tcp , buf , sizeof(buf) - 2);
+
 	len = fetion_sip_get_length(buf);
+
 	if(strstr(buf , "\r\n\r\n") == NULL)
 		return NULL;
 	n = strlen(buf) - strlen(strstr(buf , "\r\n\r\n") + 4);
@@ -346,9 +397,8 @@ char* fetion_sip_get_response(FetionSip* sip)
 		return NULL;
 	strcpy(res , buf);
 	if(c < len)
-		while(1)
-		{
-			bzero(buf , sizeof(buf));
+	    	for(;;){
+			memset(buf , 0 , sizeof(buf));
 			c1 = tcp_connection_recv(sip->tcp , buf
 					, len -c < (sizeof(buf) - 1) ? len -c : (sizeof(buf) - 1) );
 			strcpy(res + c, buf);
@@ -591,6 +641,8 @@ void fetion_sip_parse_notification(const char* sip , int* type , int* event , ch
 		*type = NOTIFICATION_TYPE_REGISTRATION;
 	else if(strcmp(type1 , "SyncUserInfoV4") == 0)
 		*type = NOTIFICATION_TYPE_SYNCUSERINFO;
+	else if(strcmp(type1 , "PGGroup") == 0)
+	    	*type = NOTIFICATION_TYPE_PGGROUP;
 	else
 		*type = NOTIFICATION_TYPE_UNKNOWN;
 
@@ -612,6 +664,8 @@ void fetion_sip_parse_notification(const char* sip , int* type , int* event , ch
 		*event = NOTIFICATION_EVENT_SYNCUSERINFO;
 	else if(xmlStrcmp(event1 , BAD_CAST "AddBuddyApplication") == 0)
 		*event = NOTIFICATION_EVENT_ADDBUDDYAPPLICATION;
+	else if(xmlStrcmp(event1 , BAD_CAST "PGGetGroupInfo") == 0)
+	    	*event = NOTIFICATION_EVENT_PGGETGROUPINFO;
 	else
 		*event = NOTIFICATION_EVENT_UNKNOWN;
 	xmlFree(event1);
@@ -619,7 +673,9 @@ void fetion_sip_parse_notification(const char* sip , int* type , int* event , ch
 }
 void fetion_sip_parse_message(FetionSip* sip , const char* sipmsg , Message** msg)
 {
-	char len[10] , callid[10] , sequence[10] , sendtime[32] , from[50] , rep[256];
+	char len[10] , callid[10] , sequence[10] ;
+	char sendtime[32] , from[64] , rep[256];
+	char memsipuri[64];
 	char *pos = NULL;
 	xmlDocPtr doc;
 	xmlNodePtr node;
@@ -636,26 +692,38 @@ void fetion_sip_parse_message(FetionSip* sip , const char* sipmsg , Message** ms
 
 	*msg = fetion_message_new();
 
+	/* group message */
+	if(strstr(from , "PG") != NULL){
+	    fetion_message_set_pguri(*msg , from);
+	    memset(memsipuri , 0 , sizeof(memsipuri));
+	    fetion_sip_get_attr(sipmsg , "SO" , memsipuri);
+	    fetion_message_set_sipuri(*msg , memsipuri);
+	}else{
+	    fetion_message_set_sipuri(*msg , from);
+	}
+
 	pos = strstr(sipmsg , "\r\n\r\n") + 4;
 	doc = xmlReadMemory(pos , strlen(pos) , "UTF-8" , NULL , XML_PARSE_NOERROR);
-	fetion_message_set_sipuri(*msg , from);
 	fetion_message_set_time(*msg , convert_date(sendtime));
-	if(doc != NULL)
-	{
+
+	if(doc != NULL){
 		node = xmlDocGetRootElement(doc);
 		pos = (char*)xmlNodeGetContent(node);
 		fetion_message_set_message(*msg , pos);
 		free(pos);
 		xmlFreeDoc(doc);
-	}
-	else
-	{
+	}else{
 		fetion_message_set_message(*msg , pos);
 	}
 
 	bzero(rep , sizeof(rep));
-	sprintf(rep ,"SIP-C/4.0 200 OK\r\nF: %s\r\nI: %s\r\nQ: %s\r\n\r\n"
-				, from , callid , sequence );
+	if(strstr(from , "PG") == NULL)
+	    sprintf(rep ,"SIP-C/4.0 200 OK\r\nF: %s\r\nI: %s\r\nQ: %s\r\n\r\n"
+				    , from , callid , sequence );
+	else
+	    sprintf(rep ,"SIP-C/4.0 200 OK\r\nI: %s\r\nQ: %s\r\nF: %s\r\n\r\n"
+				    , callid , sequence , from);
+
 	tcp_connection_send(sip->tcp , rep , strlen(rep));
 }
 void fetion_sip_parse_invitation(FetionSip* sip , Proxy *proxy , const char* sipmsg
@@ -963,7 +1031,38 @@ void fetion_sip_parse_sysmsg(const char* sipmsg , int *type
 	xmlFree(res);
 
 }
-#define _XOPEN_SOURCE
+
+int fetion_sip_parse_sipc(const char *sipmsg , int *callid , char **xml)
+{
+	char callid_str[16];
+	char *pos;
+	int n;
+	char code[5];
+
+	pos = strstr(sipmsg , " ") + 1;
+	n = strlen(pos) - strlen(strstr(pos , " "));
+	strncpy(code , pos , n);
+	
+	fetion_sip_get_attr(sipmsg , "I" , callid_str);
+	*callid = atoi(callid_str);
+	
+	pos = strstr(sipmsg , "\r\n\r\n");
+
+	if(pos)
+	    pos += 4;
+	else{
+	    *xml = NULL;
+	    return -1;
+	}
+	
+	*xml = (char*)malloc(strlen(pos) + 1);
+	memset(*xml , 0 , strlen(pos) + 1);
+	strcpy(*xml , pos);
+
+	return atoi(code);
+
+}
+
 struct tm convert_date(const char* date)
 {
 	char* pos = strstr(date , ",") + 2;
