@@ -18,8 +18,15 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include "fetion_include.h"
+#include <openfetion.h>
 
+static int fetion_user_download_portrait_again(const char* filepath , const char* buf , Proxy *proxy);
+static char* generate_set_state_body(StateType state);
+static char* generate_set_moodphrase_body(const char* customConfigVersion
+				, const char* customConfig , const char* personalVersion ,  const char* moodphrase);
+static char* generate_update_information_body(User* user);
+static char* generate_keep_alive_body();
+static void parse_set_moodphrase_response(User* user , const char* sipmsg);
 
 User* fetion_user_new(const char* no , const char* password)
 {
@@ -43,6 +50,7 @@ User* fetion_user_new(const char* no , const char* password)
 	strcpy(user->customConfigVersion , "0");
 	user->contactList = fetion_contact_new();
 	user->groupList = fetion_group_new();
+	user->pggroup = NULL;
 	user->sip = NULL;
 	user->verification = NULL;
 	user->customConfig = NULL;
@@ -338,12 +346,21 @@ int fetion_user_upload_portrait(User* user , const char* filename)
 }
 
 int fetion_user_download_portrait(User* user , const char* sipuri)
+{
+    	char uri[256];
+	char *server = user->config->portraitServerName;
+	char *portraitPath = user->config->portraitServerPath;
+	sprintf(uri , "/%s/getportrait.aspx" , portraitPath);
+
+	return fetion_user_download_portrait_with_uri(user , sipuri , server , uri);
+}
+
+int fetion_user_download_portrait_with_uri(User *user , const char *sipuri
+       	, const char *server , const char *portraitpath)
 {
 	char buf[2048] , *ip , *pos = NULL;
 	FILE *f = NULL;
 	char filename[256];
-	char *server = user->config->portraitServerName;
-	char *portraitPath = user->config->portraitServerPath;
 	char *encodedSipuri , *encodedSsic , replyCode[4] = { 0 };
 	char *friendSid = NULL;
 	Config *config = user->config;
@@ -366,13 +383,14 @@ int fetion_user_download_portrait(User* user , const char* sipuri)
 	free(friendSid);
 	encodedSipuri = http_connection_encode_url(sipuri);
 	encodedSsic = http_connection_encode_url(user->ssic);
-	sprintf(buf , "GET /%s/getportrait.aspx?Uri=%s"
-				  "&Size=120&c=%s HTTP/1.1\r\n"
-				  "User-Agent: IIC2.0/PC 3.6.1900\r\n"
-				  "Accept: image/pjpeg;image/jpeg;image/bmp;"
-				  "image/x-windows-bmp;image/png;image/gif\r\n"
-				  "Host: %s\r\nConnection: Keep-Alive\r\n\r\n"
-				  , portraitPath , encodedSipuri , encodedSsic , server);
+	sprintf(buf , "GET %s?Uri=%s"
+			  "&Size=120&c=%s HTTP/1.1\r\n"
+			  "User-Agent: IIC2.0/PC "PROTO_VERSION"\r\n"
+			  "Accept: image/pjpeg;image/jpeg;image/bmp;"
+			  "image/x-windows-bmp;image/png;image/gif\r\n"
+			  "Host: %s\r\nConnection: Keep-Alive\r\n\r\n"
+			  , portraitpath , encodedSipuri , encodedSsic , server);
+
 	tcp = tcp_connection_new();
 	if(config->proxy != NULL && config->proxy->proxyEnabled)
 		tcp_connection_connect_with_proxy(tcp , ip , 80 , config->proxy);
@@ -457,7 +475,7 @@ end:
 	tcp = NULL;
 	return 0;
 }
-int fetion_user_download_portrait_again(const char* filepath , const char* buf , Proxy* proxy)
+static int fetion_user_download_portrait_again(const char* filepath , const char* buf , Proxy* proxy)
 {
 	char location[1024] = { 0 };
 	char httpHost[50] = { 0 };
@@ -724,7 +742,7 @@ Contact* fetion_user_parse_syncuserinfo_body(const char* body , User* user)
 	xmlFreeDoc(doc);
 	return currentContact;
 }
-char* generate_set_state_body(StateType state)	
+static char* generate_set_state_body(StateType state)	
 {
 	char s[5];
 	char data[] = "<args></args>";
@@ -742,7 +760,7 @@ char* generate_set_state_body(StateType state)
 	xmlFreeDoc(doc);
 	return xml_convert(res);
 }
-char* generate_set_moodphrase_body(const char* customConfigVersion
+static char* generate_set_moodphrase_body(const char* customConfigVersion
 		, const char* customConfig , const char* personalVersion
 		,  const char* moodphrase)
 {
@@ -763,7 +781,7 @@ char* generate_set_moodphrase_body(const char* customConfigVersion
 	xmlFreeDoc(doc);
 	return xml_convert(res);
 }
-char* generate_update_information_body(User* user)
+static char* generate_update_information_body(User* user)
 {
 	char args[] = "<args></args>";
 	char gender[5];
@@ -787,7 +805,7 @@ char* generate_update_information_body(User* user)
 	xmlFreeDoc(doc);
 	return xml_convert(res);
 }
-char* generate_keep_alive_body()
+static char* generate_keep_alive_body()
 {
 	char args[] = "<args></args>";
 	xmlChar *res;
@@ -801,7 +819,7 @@ char* generate_keep_alive_body()
 	xmlFreeDoc(doc);
 	return xml_convert(res);
 }
-void parse_set_moodphrase_response(User* user , const char* sipmsg)
+static void parse_set_moodphrase_response(User* user , const char* sipmsg)
 {
 	char *pos;
 	xmlChar* res;
