@@ -46,7 +46,7 @@ void fx_history_initialize(FxHistory* fxhistory)
 	bzero(title , sizeof(title));
 
 	fxhistory->dialog = gtk_dialog_new();
-	sprintf(title , "查看与[%s]的聊天记录" , fxhistory->name );
+	sprintf(title , _("View logs with [%s]") , fxhistory->name );
 	gtk_window_set_title(GTK_WINDOW(fxhistory->dialog) , title);
 	gtk_widget_set_usize(fxhistory->dialog , 750 , 550);
 	pb = gdk_pixbuf_new_from_file(SKIN_DIR"history.png" , NULL);
@@ -57,27 +57,27 @@ void fx_history_initialize(FxHistory* fxhistory)
 	fxhistory->toolbar = gtk_toolbar_new();
 	gtk_toolbar_set_style(GTK_TOOLBAR(fxhistory->toolbar) , GTK_TOOLBAR_BOTH_HORIZ);
 	gtk_box_pack_start(vbox , fxhistory->toolbar , FALSE , TRUE , 0);
-	label1 = gtk_label_new("显示最新的");
+	label1 = gtk_label_new(_("Show the most recent"));
 	gtk_container_add(GTK_CONTAINER(fxhistory->toolbar) , label1);
 	model = fx_history_create_count_model();
 	fxhistory->daycombo = gtk_combo_box_entry_new_with_model(model , 0);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(fxhistory->daycombo) , 1);
 	gtk_widget_set_usize(fxhistory->daycombo , 60 , 20);
 	gtk_container_add(GTK_CONTAINER(fxhistory->toolbar) , fxhistory->daycombo);
-	label2 = gtk_label_new("条聊天记录");
+	label2 = gtk_label_new(_("mesage"));
 	gtk_container_add(GTK_CONTAINER(fxhistory->toolbar) , label2);
 	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"refresh.png" , 16 , 16 , NULL);
 	refresh_icon = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
 	gtk_toolbar_append_item(GTK_TOOLBAR(fxhistory->toolbar)
-						  , "刷新" , NULL , NULL , refresh_icon
+						  , _("Refresh") , NULL , NULL , refresh_icon
 						  , G_CALLBACK(fx_history_on_refresh_clicked)
 						  , fxhistory);
 	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"login.png" , 16 , 16 , NULL);
 	today_icon = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
 	gtk_toolbar_append_item(GTK_TOOLBAR(fxhistory->toolbar)
-						  , "今天" , NULL , NULL , today_icon
+						  , _("Today") , NULL , NULL , today_icon
 						  , G_CALLBACK(fx_history_on_today_clicked)
 						  , fxhistory);
 
@@ -85,21 +85,21 @@ void fx_history_initialize(FxHistory* fxhistory)
 	yest_icon = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
 	gtk_toolbar_append_item(GTK_TOOLBAR(fxhistory->toolbar)
-						  , "昨天" , NULL , NULL , yest_icon
+						  , _("Yestorday") , NULL , NULL , yest_icon
 						  , G_CALLBACK(fx_history_on_yestorday_clicked)
 						  , fxhistory);
 	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"login.png" , 16 , 16 , NULL);
 	month_icon = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
 	gtk_toolbar_append_item(GTK_TOOLBAR(fxhistory->toolbar)
-						  , "本月" , NULL , NULL , month_icon
+						  , _("This Month") , NULL , NULL , month_icon
 						  , G_CALLBACK(fx_history_on_month_clicked)
 						  , fxhistory);
 	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"login.png" , 16 , 16 , NULL);
 	all_icon = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
 	gtk_toolbar_append_item(GTK_TOOLBAR(fxhistory->toolbar)
-						  , "全部" , NULL , NULL , all_icon
+						  , _("All") , NULL , NULL , all_icon
 						  , G_CALLBACK(fx_history_on_all_clicked)
 						  , fxhistory);
 
@@ -107,7 +107,7 @@ void fx_history_initialize(FxHistory* fxhistory)
 	exp_icon = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
 	gtk_toolbar_append_item(GTK_TOOLBAR(fxhistory->toolbar)
-						  , "导出" , NULL , NULL , exp_icon
+						  , _("Export") , NULL , NULL , exp_icon
 						  , G_CALLBACK(fx_history_on_export_clicked)
 						  , fxhistory);
 	fxhistory->textview = gtk_text_view_new();
@@ -127,7 +127,7 @@ void fx_history_initialize(FxHistory* fxhistory)
 	gtk_container_add(GTK_CONTAINER(scrollwindow) , fxhistory->textview);
 	gtk_box_pack_start(vbox , scrollwindow , TRUE , TRUE , 5);
 	fxhistory->closebtn = gtk_button_new();
-	gtk_button_set_label(GTK_BUTTON(fxhistory->closebtn) , "关闭");
+	gtk_button_set_label(GTK_BUTTON(fxhistory->closebtn) , _("Close"));
 	g_signal_connect(fxhistory->closebtn , "clicked" , G_CALLBACK(fx_history_on_close_clicked) , fxhistory->dialog);
 	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(fxhistory->dialog)->action_area) , fxhistory->closebtn);
 	list = fetion_history_get_list(config , fxhistory->userid , 20);
@@ -153,7 +153,7 @@ void fx_history_bind(FxHistory* fxhistory , FxList *list)
 		bzero(text , sizeof(text));
 		bzero(time , sizeof(time));
 		history = (History*)(cur->data);
-		strftime(time , sizeof(time) , "%m月%d日 %H:%M:%S" , &(history->sendtime));
+		strftime(time , sizeof(time) , _("%m-%d %H:%M:%S") , &(history->sendtime));
 		if(history->issend){
 			sprintf(text , "%s(%s) %s" , history->name , fxmain->user->sId , time );
 			gtk_text_buffer_insert_with_tags_by_name(buffer
@@ -241,7 +241,7 @@ void fx_history_on_export_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 	GtkWidget *dialog;
 	char text[1024];
 
-	dialog = gtk_file_chooser_dialog_new ("导出文件",
+	dialog = gtk_file_chooser_dialog_new (_("Export File"),
 						  GTK_WINDOW(fxhistory->fxmain->window),
 						  GTK_FILE_CHOOSER_ACTION_SAVE,
 						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -250,7 +250,7 @@ void fx_history_on_export_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 
 	gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER (dialog), TRUE);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), getenv("HOME"));
-	sprintf(text , "与%s的聊天记录.txt" , fxhistory->name);
+	sprintf(text , _("logs with %s.txt") , fxhistory->name);
 	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), text);
 
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
