@@ -398,7 +398,7 @@ void fx_many_initialize(FxMany* fxmany)
 	fxmany->dialog = gtk_dialog_new();
 	pb = gdk_pixbuf_new_from_file(SKIN_DIR"groupsend.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxmany->dialog) , pb);
-	gtk_window_set_title(GTK_WINDOW(fxmany->dialog) , "短信群发");
+	gtk_window_set_title(GTK_WINDOW(fxmany->dialog) , _("SMS To Many"));
 	gtk_widget_set_usize(fxmany->dialog , 660 , 520);
 	gtk_container_set_border_width(GTK_CONTAINER(fxmany->dialog) , 5);
 
@@ -410,7 +410,7 @@ void fx_many_initialize(FxMany* fxmany)
 	gtk_box_pack_start(GTK_BOX(fxmany->hbox) , lbox , FALSE , FALSE , 5);
 	action_area = GTK_DIALOG(fxmany->dialog)->action_area;
 	/*left top area*/
-	lt_frame = gtk_frame_new("请选择好友");
+	lt_frame = gtk_frame_new(_("Choose Contacts"));
 	gtk_widget_set_usize(lt_frame , 180 , 0);
 	model = fx_many_create_all_model(fxmany);
 	fxmany->tree = gtk_tree_view_new_with_model(model);
@@ -446,7 +446,7 @@ void fx_many_initialize(FxMany* fxmany)
 	gtk_tree_view_columns_autosize(GTK_TREE_VIEW(fxmany->selected));
 	
 	fx_many_create_selected_column(fxmany);
-	lb_frame = gtk_frame_new("已选择的好友");
+	lb_frame = gtk_frame_new(_("Contacts Selected"));
 	gtk_widget_set_usize(lb_frame , 0 , 160);
 	gtk_box_pack_start(GTK_BOX(lbox) , lb_frame , FALSE , FALSE , 5);
 	gtk_container_add(GTK_CONTAINER(lb_frame) , scrollwindow1);
@@ -494,12 +494,12 @@ void fx_many_initialize(FxMany* fxmany)
  	fxmany->send_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(fxmany->send_text));
 	gtk_text_buffer_get_iter_at_offset(fxmany->send_buffer , &fxmany->send_iter , 0);
 
-	close_button = gtk_button_new_with_label("关闭");
+	close_button = gtk_button_new_with_label(_("Close"));
 	gtk_widget_set_usize(close_button , 100 , 30);
 	gtk_box_pack_start(GTK_BOX(action_area) , close_button , FALSE , TRUE , 2);
 	g_signal_connect(close_button , "clicked" , G_CALLBACK(fx_many_on_close_clicked) , fxmany->dialog);
 
-	send_button = gtk_button_new_with_label("发送");
+	send_button = gtk_button_new_with_label(_("Send"));
 	gtk_widget_set_usize(send_button , 100 , 30);
 	gtk_box_pack_start(GTK_BOX(action_area) , send_button , FALSE , TRUE , 2);
 	g_signal_connect(send_button , "clicked" , G_CALLBACK(fx_many_on_send_clicked) , fxmany);
@@ -524,7 +524,7 @@ static void fx_many_on_send_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 
 	if(fxmany->chooseCount == 0)
 	{
-		fx_many_add_information(fxmany , "您还没有选择好友");
+		fx_many_add_information(fxmany , _("You have not selected contacts"));
 		return;
 	}	
 	
@@ -551,7 +551,7 @@ static void* fx_many_sms_send_func(void* data)
 	text = gtk_text_buffer_get_text(fxmany->send_buffer , &begin , &end , TRUE);
 	if(strlen(text) == 0)
 	{
-		fx_many_add_information(fxmany , "请输入消息内容");
+		fx_many_add_information(fxmany , _("Please input the contents of message"));
 		return NULL;
 	}
 	gtk_text_buffer_delete(fxmany->send_buffer , &begin , &end);
@@ -568,11 +568,10 @@ static void* fx_many_sms_send_func(void* data)
 			if(fetion_conversation_send_sms_to_phone_with_reply(conv
 						, text , &daycount , &monthcount) > 0){
 				bzero(alertmsg , sizeof(alertmsg));
-				sprintf(alertmsg , "消息“%s”成功发送至“%s”,"
-						" 今天已发送短信息%d条，本月已发送%d条\n"
-						, text , name , daycount , monthcount);
+				sprintf(alertmsg , _("Mesage \"%s\" has been sent to \"%s\". Today you have sent %d and this "
+						 "month %d\n") , text , name , daycount , monthcount);
 			}else{
-				sprintf(alertmsg , "消息“%s”未发送至“%s”\n" , text , name);
+				sprintf(alertmsg , _("Mesage \"%s\" did not send to \"%s\"\n") , text , name);
 			}
 			fx_many_add_information(fxmany , alertmsg);
 			free(conv);
