@@ -20,11 +20,6 @@
 
 #include "fx_include.h"
 
-gchar * _(const gchar *string)
-{
-	return(g_locale_to_utf8(string, -1, NULL, NULL, NULL));
-}
-
 char* fx_util_get_state_name(StateType type)
 {
 	char *name = (char*)malloc(48);
@@ -32,37 +27,37 @@ char* fx_util_get_state_name(StateType type)
 	switch(type)
 	{
 		case P_ONLINE:
-			strcpy(name , "[在线]");
+			strcpy(name , _("[Online]"));
 			break;
 		case P_BUSY:
-			strcpy(name , "[忙碌]");
+			strcpy(name , _("[Busy]"));
 			break;
 		case P_AWAY:
-			strcpy(name , "[离开]");
+			strcpy(name , _("[Leave]"));
 			break;
 		case P_HIDDEN:
-			strcpy(name , "[隐身]");
+			strcpy(name , _("[Hide]"));
 			break;
 		case P_OUTFORLUNCH:
-			strcpy(name , "[外出就餐]");
+			strcpy(name , _("[Eating out]"));
 			break;
 		case P_DONOTDISTURB:
-			strcpy(name , "[请勿打扰]");
+			strcpy(name , _("[Do Not Disturb]"));
 			break;
 		case P_RIGHTBACK:
-			strcpy(name , "[马上回来]");
+			strcpy(name , _("[Be Back Soon]"));
 			break;
 		case P_MEETING:
-			strcpy(name , "[会议中]");
+			strcpy(name , _("[Meeting]"));
 			break;
 		case P_ONTHEPHONE:
-			strcpy(name , "[电话中]");
+			strcpy(name , _("[Calling]"));
 			break;
 		default:
 			if(type > 400 && type < 500)
-				strcpy(name , "[在线]");
+				strcpy(name , _("[Online]"));
 			else
-				strcpy(name , "[未知状态]");
+				strcpy(name , _("[Unknown Statement]"));
 			break;
 	}
 	return name;
